----------------------------------------------------------------------------------------------------
-- FuBar 3 Plugin for Wardrobe-AL
-- Author: Swizstera
-- Date: 10/27/2008
--
-- prototype shamelessly taken from Broker2FuBar implementation
----------------------------------------------------------------------------------------------------


-- do nothing if FuBar isn't present
if not FuBar2DB then return end

local LFBP = LibStub:GetLibrary("LibFuBarPlugin-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("Wardrobe")

WardrobeAce.pluginPrototype = {}
WardrobeAce.pluginPrototypeMetatable = { __index = WardrobeAce.pluginPrototype }

local pluginPrototype = WardrobeAce.pluginPrototype

local db = WardrobeAce.db



----------------------------------------------------------------------------------------------------

function WardrobeAce:InitFuBarPlugin()

		WardrobeAce.FuBarPlugin = setmetatable({
				name             = "Wardrobe",
			}, self.pluginPrototypeMetatable)

		LFBP:Embed(WardrobeAce.FuBarPlugin)

--		WardrobeAce.FuBarPlugin.db = WardrobeAce.db
		WardrobeAce.FuBarPlugin:Initialize()

end

function WardrobeAce:ToggleFuBarPlugin()

	  WardrobeAce.db.profile.fubar.enabled = not WardrobeAce.db.profile.fubar.enabled

	  if(WardrobeAce.db.profile.fubar.enabled) then
	    WardrobeAce:OnEnableFuBarPlugin()
	  else
		WardrobeAce:OnDisableFuBarPlugin()
	  end

end

function WardrobeAce:OnEnableFuBarPlugin()

	WardrobeAce.FuBarPlugin:Enable()

	self:RegisterEvent("UNIT_INVENTORY_CHANGED")

end

function WardrobeAce:OnDisableFuBarPlugin()
	if not WardrobeAce.FuBarPlugin then return end

	self:UnregisterEvent("UNIT_INVENTORY_CHANGED")

	WardrobeAce.FuBarPlugin:Disable()

end

-- UNIT_INVENTORY_CHANGED event
function WardrobeAce:UNIT_INVENTORY_CHANGED()

	if not WardrobeAce.FuBarPlugin then return end

	-- update the text on the panel
	if (Chronos) then
		Chronos.scheduleByName("WardrobeFuUpdate", .2, function() WardrobeAce.FuBarPlugin:OnFuBarUpdateText() end)
	else
		WardrobeAce.FuBarPlugin:OnFuBarUpdateText()
	end

end


--		ShowMinimapIcon = AceConfigOptions.FuBar.ShowMiniMapIcon,
--		RequireClick = AceConfigOptions.FuBar.RequireClick,


----------------------------------------------------------------------------------------------------
-- Menu table
local fuBarDewDropTable = {
	name = L["Wardrobe-AL"],
	desc = L["Wardrobe-AL"],
	type = 'group',
	groupType = 'inline',
	args = {
		Header = {
			type = "header",
			name = L["Wardrobe-AL"],
			order = 1,
		},
		EditWardrobes = AceConfigOptions.args.General.args.EditWardrobes,
		ShowMinimapIcon = AceConfigOptions.args.General.args.ShowMinimapIcon,
		LockButton = AceConfigOptions.args.General.args.LockButton,
		ItemTooltips = AceConfigOptions.args.General.args.ItemTooltips,
		AutoSwap = AceConfigOptions.args.General.args.AutoSwap,
		AutoSwapInBG = AceConfigOptions.args.General.args.AutoSwapInBG,
		ShowTextPrefix = AceConfigOptions.args.FuBar.args.ShowTextPrefix,
		icon = {
			type = "toggle",
			name = "Show icon",
			desc = "Show icon",
			set = function()
				WardrobeAce.FuBarPlugin:ToggleFuBarIconShown()
				WardrobeAce.FuBarPlugin:OnFuBarUpdateText()
			end,
			get = function() return WardrobeAce.FuBarPlugin:IsFuBarIconShown() end,
			order = -4,
		},
		text = {
			type = "toggle",
			name = "Show text",
			desc = "Show text",
			set = function()
				WardrobeAce.FuBarPlugin:ToggleFuBarTextShown()
				WardrobeAce.FuBarPlugin:OnFuBarUpdateText()
			end,
			get = function() return WardrobeAce.FuBarPlugin:IsFuBarTextShown() end,
			order = -3,
		},
		position = {
			type = "text",
			name = "Position",
			desc = "Position",
			validate = {
				LEFT = L["Left"],
				CENTER = L["Center"],
				RIGHT = L["Right"]
			},
			get = function() return WardrobeAce.db.profile.fubar.position end,
			set = function(val)
			Wardrobe.Debug("panel side=",val)
				WardrobeAce.db.profile.fubar.position = val
				if WardrobeAce.FuBarPlugin:GetPanel() and WardrobeAce.FuBarPlugin:GetPanel().SetPluginSide then
					WardrobeAce.FuBarPlugin:GetPanel():SetPluginSide(WardrobeAce.FuBarPlugin, val)
				end
			end,
			order = -2,
		},
		AddonSettings = {

			type = "execute",
			name = L["Addon Settings"],
			desc = L["Addon Settings"],
			order = -1,
			func = function() WardrobeAce.ToggleConfig() end,
		},
	}
}


function pluginPrototype:Initialize()

	self.db = WardrobeAce.db

	self:SetFuBarOption("cannotAttachToMinimap", true)
	self:SetFuBarOption("tooltipType", "GameTooltip")
	self:SetFuBarOption("hasNoColor", false)
	self:SetFuBarOption("cannotDetachTooltip", true)
	self:SetFuBarOption("hideWithoutStandby", true)
	self:SetFuBarOption("iconPath", [[Interface\AddOns\Wardrobe\Images\Wardrobe]])
	self:SetFuBarOption("hasIcon", true)
	self:SetFuBarOption("defaultPosition", "RIGHT")
	self:SetFuBarOption("tooltipHiddenWhenEmpty", true)
	self:SetFuBarOption('configType', 'None')
	pluginPrototype.OnMenuRequest = fuBarDewDropTable
	LFBP:OnEmbedInitialize(self)

	if (self.db.profile.fubar.rightClickOpens == 3 ) then
		self:SetFuBarOption("configType", "Dewdrop-2.0")
	else
		self:SetFuBarOption('configType', 'None')
	end

end

function pluginPrototype:Enable()

	if self.enabled then return end
	self.enabled = true
	LFBP:OnEmbedEnable(self)

	if(FuBar:GetNumPanels() == 0) then
		return
	end

	if (self.db.profile.fubar.panelId > FuBar:GetNumPanels()) then
		self.db.profile.fubar.panelId = 1
	end

	local panel = FuBar:GetPanel(self.db.profile.fubar.panelId)

	panel:AddPlugin(self, nil, self.db.profile.fubar.position)
	self:SetPanel(panel)

	self:OnFuBarUpdateText()

end

function pluginPrototype:Disable()
	if not self.enabled then return end
	self.enabled = false
	LFBP:OnEmbedDisable(self)
end

function pluginPrototype:IsEnabled()
	return self.enabled
end


function pluginPrototype:OnFuBarClick(button, down)

	if(button == "RightButton") then
		Wardrobe.Debug("self.db.profile.fubar.rightClickOpens=", self.db.profile.fubar.rightClickOpens)
		Wardrobe.RightClickOpenFunction[self.db.profile.fubar.rightClickOpens].func()
	else
		self:ShowWardrobeMenu()
	end
end


-- Show the wardrobe popup menu at the cursor
function pluginPrototype:ShowWardrobeMenu()

	    Wardrobe.ShowUIMenu()

--	ToggleDropDownMenu(1, nil, WardrobeEquipDropDown, "cursor")

end


function pluginPrototype:OnUpdateFuBarTooltip()

	if self.db.char.mustClickUIButton then
		local menustring = Wardrobe.RightClickOpenFunction[WardrobeAce.db.profile.fubar.rightClickOpens].desc

		GameTooltip:AddLine("|cffffff00" .. L["Select your outfit or configure Wardrobe"])
		GameTooltip:AddLine("|cffffff00" .. L["Right-click|r to "]..menustring)
	end

end

function pluginPrototype:OnFuBarEnter(motion)

	if not self.db.char.mustClickUIButton then
		self:ShowWardrobeMenu()
	end

end

-- Update the text value to appear on the FuBar
function pluginPrototype:OnFuBarUpdateText()

	if(self.db.profile.fubar.enabled) then
		-- get the list of outfits
		local outfitText = Wardrobe.GetActiveOutfitsTextList(Wardrobe.MaxBarTextLen)

		-- prepend the label
		if (self.db.profile.fubar.showTextPrefix) then
			outfitText = L["Wardrobe: "]..outfitText
		end

		-- set the text
		self:SetFuBarText(outfitText)
	end

end
